@@ -4,6 +4,7 @@ __maintainer__ = "Jake Nunemaker"
 __email__ = ["jake.nunemaker@nrel.gov"]
 
 
+import os
 import re
 import datetime as dt
 import collections.abc as collections
@@ -163,6 +164,20 @@ class ProjectManager:
 
         return self._phases
 
+    @property
+    def _capex_categories(self):
+        """Returns CapEx categories for phases in `self._install_phases`."""
+
+        out = {}
+        for p in self._install_phases:
+            try:
+                out[p.__name__] = p.capex_category
+
+            except AttributeError:
+                out[p.__name__] = "Misc."
+
+        return out
+
     @property
     def project_params(self):
         """Returns defined project parameters, if found."""
@@ -790,6 +805,50 @@ class ProjectManager:
 
         return self.weather.iloc[ceil(start) :].copy().to_records()
 
+    def outputs(self, include_logs=False, npv_detailed=False):
+        """Returns dict of all available outputs."""
+
+        out = {
+            # Times
+            "project_time": self.project_time,
+            "installation_time": self.installation_time,
+            # Costs
+            "capex_breakdown": self.capex_breakdown,
+            "capex_breakdown_per_kw": self.capex_breakdown_per_kw,
+            "turbine_capex": self.turbine_capex,
+            "turbine_capex_per_kw": self.turbine_capex_per_kw,
+            "installation_capex": self.installation_capex,
+            "installation_capex_per_kw": self.installation_capex_per_kw,
+            "system_capex": self.system_capex,
+            "system_capex_per_kw": self.system_capex_per_kw,
+            "overnight_capex": self.overnight_capex,
+            "overnight_capex_per_kw": self.overnight_capex_per_kw,
+            "soft_capex": self.soft_capex,
+            "soft_capex_per_kw": self.soft_capex_per_kw,
+            "bos_capex": self.bos_capex,
+            "bos_capex_per_kw": self.bos_capex_per_kw,
+            "project_capex": self.project_capex,
+            "project_capex_per_kw": self.project_capex_per_kw,
+            "total_capex": self.total_capex,
+            "total_capex_per_kw": self.total_capex_per_kw,
+            "npv": self.npv,
+        }
+
+        if include_logs:
+            out["logs"] = self.actions
+
+        if npv_detailed:
+            out = {
+                **out,
+                **{
+                    "cash_flow": self.cash_flow,
+                    "monthly_revenue": self.monthly_revenue,
+                    "monthly_expenses": self.monthly_expenses,
+                },
+            }
+
+        return out
+
     @property
     def capacity(self):
         """Returns project capacity in MW."""
@@ -1114,6 +1173,63 @@ class ProjectManager:
 
         return capex
 
+    @property
+    def capex_breakdown(self):
+        """Returns CapEx breakdown by category."""
+
+        unique = np.unique(
+            [*self.system_costs.keys(), *self.installation_costs.keys()]
+        )
+        categories = {}
+
+        for phase in unique:
+            for base, cat in self._capex_categories.items():
+                if base in phase:
+                    categories[phase] = cat
+                    break
+
+        missing = [p for p in unique if p not in categories.keys()]
+        if missing:
+            print(
+                f"Warning: CapEx category not found for {missing}. "
+                f"Added to 'Misc.'"
+            )
+
+            for phase in missing:
+                categories[phase] = "Misc."
+
+        outputs = {}
+        for phase, cost in self.system_costs.items():
+            name = categories[phase]
+            if name in outputs.keys():
+                outputs[name] += cost
+
+            else:
+                outputs[name] = cost
+
+        for phase, cost in self.installation_costs.items():
+            name = categories[phase] + " Installation"
+            if name in outputs.keys():
+                outputs[name] += cost
+
+            else:
+                outputs[name] = cost
+
+        outputs["Turbine"] = self.turbine_capex
+        outputs["Soft"] = self.soft_capex
+        outputs["Project"] = self.project_capex
+
+        return outputs
+
+    @property
+    def capex_breakdown_per_kw(self):
+        """Returns CapEx per kW breakdown by category."""
+
+        return {
+            k: v / (self.capacity * 1000)
+            for k, v in self.capex_breakdown.items()
+        }
+
     @property
     def bos_capex(self):
         """Returns total balance of system CapEx."""
@@ -1134,9 +1250,7 @@ class ProjectManager:
 
     @property
     def turbine_capex(self):
-        """
-        Returns the total turbine CAPEX.
-        """
+        """Returns the total turbine CAPEX."""
 
         _capex = self.project_params.get("turbine_capex", 1300)
         try:
@@ -1157,7 +1271,7 @@ class ProjectManager:
     def turbine_capex_per_kw(self):
         """Returns the turbine CapEx/kW."""
 
-        _capex = self.project_params.get("turbine_capex", None)
+        _capex = self.project_params.get("turbine_capex", 1300)
         return _capex
 
     @property
@@ -1263,6 +1377,38 @@ class ProjectManager:
 
         export_library_specs("config", file_name, self.config)
 
+    def export_project_logs(self, filepath, level="ACTION"):
+        """
+        Exports the project logs to a .csv file.
+
+        Parameters
+        ----------
+        filepath : str
+            Filepath to save logs at.
+        level : str, optional
+            Log level to save.
+            Options: 'ACTION' | 'DEBUG'
+            Default: 'ACTION'
+        """
+
+        dirs = os.path.split(filepath)[0]
+        if dirs and not os.path.isdir(dirs):
+            os.makedirs(dirs)
+
+        if level == "ACTION":
+            out = pd.DataFrame(self.actions)
+
+        elif level == "DEBUG":
+            out = pd.DataFrame(self.logs)
+
+        else:
+            raise ValueError(
+                f"Unrecognized level '{level}'."
+                " Must be 'ACTION' or 'DEBUG'."
+            )
+
+        out.to_csv(filepath, index=False)
+
 
 class ProjectProgress:
     """Class to store, parse and return project progress data."""
