@@ -22,6 +22,7 @@ class MooredSubInstallation(InstallPhase):
     """
 
     phase = "Moored Substructure Installation"
+    capex_category = "Substructure"
 
     #:
     expected_config = {
@@ -80,6 +81,7 @@ class MooredSubInstallation(InstallPhase):
         self.distance = self.config["site"]["distance"]
         self.num_turbines = self.config["plant"]["num_turbines"]
 
+        self.initialize_port()
         self.initialize_substructure_production()
         self.initialize_turbine_assembly()
         self.initialize_queue()
